@@ -3,6 +3,7 @@ from django.core.urlresolvers import reverse
 
 from netcash.models import NetcashGateway, NetcashOrder
 from netcash.forms import NetcashForm
+import netcash.signals
 
 class NetcashTest(TestCase):
 
@@ -22,6 +23,15 @@ class NetcashTest(TestCase):
 
     def test_data_request(self):
 
+        # signal handler
+        def data_handler(sender, order, **kwargs):
+            data_handler.called = True
+            data_handler.order = order
+        data_handler.called = False
+        data_handler.order = None
+
+        netcash.signals.data.connect(data_handler)
+
         # this will create an order
         form = NetcashForm(initial={
             'p3': 'description',
@@ -29,6 +39,8 @@ class NetcashTest(TestCase):
         })
         reference = str(form.order.pk)
 
+        self.assertFalse(data_handler.called)
+
         # ... user posts the form and pays the purchase on netcash.co.za site
         # ... then Netcash sends a notification to our Data URL
 
@@ -47,3 +59,7 @@ class NetcashTest(TestCase):
         self.assertEqual(order.Amount, 100)
         self.assertEqual(order.RETC, '123')
         self.assertEqual(order.gateway, self.gateway)
+
+        self.assertTrue(data_handler.called)
+        self.assertEqual(data_handler.order, order)
+
